@@ -22,3 +22,11 @@ class RestrictForeignKey(ForeignKey):
         if 'name' not in dialect_kw and isinstance(column, str):
             dialect_kw["name"] = column.replace(".", "_") + "_fkey"
         super().__init__(column, **dialect_kw)
+
+
+class SetNullForeignKey(ForeignKey):
+    def __init__(self, column, **dialect_kw):
+        dialect_kw['onupdate'] = dialect_kw["ondelete"] = "SET NULL"
+        if 'name' not in dialect_kw and isinstance(column, str):
+            dialect_kw["name"] = column.replace(".", "_") + "_fkey"
+        super().__init__(column, **dialect_kw)
